@@ -1,4 +1,4 @@
-VERSION="1.3.0"
+VERSION="1.3.1"
 
 #set -x
 
@@ -130,10 +130,10 @@ run_hooks() {
         # The former is however a bit better when it comes to security. On the other hand
         # running these hooks imply some level of trust; surely one doesn't clone somebody
         # else's dotfiles repository without reviewing the hooks before doing an `rcup`?
-        find "$hook_file" -type f \( \( -user $USER -perm -100 \) -o -perm -001 \) \
-          -exec \
-            sh -c 'cd "`dirname $1`" && ./"`basename $1`"' arg0 '{}' \
-            \;
+        find "$hook_file" -type f \( \( -user $LOGNAME -perm -100 \) -o -perm -001 \) \
+          | sort | while read file; do
+            sh -c 'cd "`dirname $1`" && ./"`basename $1`"' arg0 "$file"
+          done
       else
         $DEBUG "no $when-$direction hook present for $dotfiles_dir, skipping"
       fi
@@ -147,6 +147,20 @@ de_dot() {
   echo "$1" | sed -e "s|$DEST_DIR/||" | sed -e 's/^\.//'
 }
 
+DELIMITER="\a"
+
+encode() {
+  local file="$1"
+
+  echo "$file" | tr " " "$DELIMITER"
+}
+
+decode() {
+  local file="$1"
+
+  echo "$file" | tr "$DELIMITER" " "
+}
+
 : ${RCRC:=$HOME/.rcrc}
 
 if [ -r "$RCRC" ]; then
